--------------------------------------------------------------------------------
-- |
-- Module      :  Sound.OpenAL.AL.BasicTypes
-- Copyright   :  (c) Sven Panne 2003-2004
-- License     :  BSD-style (see the file libraries/OpenAL/LICENSE)
-- 
-- Maintainer  :  sven.panne@aedion.de
-- Stability   :  provisional
-- Portability :  portable
--
-- This module corresponds to section 2.1.1 (Primitive Types) of the OpenAL
-- Specification and Reference (version 1.0).
--
--------------------------------------------------------------------------------

module Sound.OpenAL.AL.BasicTypes (
   ALboolean, ALbyte, ALshort, ALint, ALubyte, ALushort, ALuint, ALsizei,
   ALenum, ALbitfield, ALfloat, ALclampf, ALdouble, ALclampd
) where

--------------------------------------------------------------------------------

import Data.Int
import Data.Word

--------------------------------------------------------------------------------

--------------------------------------------------------------------------------

-- | Boolean (min. 1 bit)
type ALboolean = Word8

-- | Signed 2\'s complement binary integer (min. 8 bits)
type ALbyte = Word8

-- | Unsigned binary integer (min. 8 bits)
type ALubyte = Word8

-- | Signed 2\'s complement binary integer (min. 16 bits)
type ALshort = Int16

-- | Unsigned binary integer (min. 16 bits)
type ALushort = Word16

-- | Signed 2\'s complement binary integer (min. 32 bits)
type ALint = Int32

-- | Unsigned binary integer (min. 32 bits)
type ALuint = Word32

-- | Non-negatitve binary integer size (min. 32 bits)
type ALsizei = Int32

-- | Enumerated binary integer value (min. 32 bits)
type ALenum = Int32

-- | Bit field (min. 32 bits)
type ALbitfield = Word32

-- | Floating-point value (min. 32 bits)
type ALfloat = Float

-- | Floating-point value clamped to [0,1] (min. 32 bits)
type ALclampf = Float

-- | Floating-point value (min. 64 bits)
type ALdouble = Double

-- | Floating-point value clamped to [0,1] (min. 64 bits)
type ALclampd = Double
